@@ -8,6 +8,9 @@ import subprocess
 import sys
 import tarfile
 
+import ssl
+ssl._create_default_https_context = ssl._create_unverified_context
+
 try:
     from urllib.request import urlretrieve, urlopen
 except:
